==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ValueSettingsPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipLargerStreamCodecs;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import net.minecraft.class_1268;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_3965;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ValueSettingsPacket(
    class_2338 pos, int row, int value, class_1268 interactHand, class_3965 hitResult, class_2350 side, boolean ctrlDown, int behaviourIndex
) implements class_2596<class_2792> {
    public static final class_9139<class_9129, ValueSettingsPacket> CODEC = CatnipLargerStreamCodecs.composite(
        class_2338.field_48404,
        ValueSettingsPacket::pos,
        class_9135.field_48550,
        ValueSettingsPacket::row,
        class_9135.field_48550,
        ValueSettingsPacket::value,
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.HAND),
        ValueSettingsPacket::interactHand,
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.BLOCK_HIT_RESULT),
        ValueSettingsPacket::hitResult,
        class_2350.field_48450,
        ValueSettingsPacket::side,
        class_9135.field_48547,
        ValueSettingsPacket::ctrlDown,
        class_9135.field_48550,
        ValueSettingsPacket::behaviourIndex,
        ValueSettingsPacket::new
    );

    @Override
    public void apply(class_2792 listener) {
        AllHandle.onValueSettings((class_3244) listener, this);
    }

    @Override
    public class_9145<ValueSettingsPacket> method_65080() {
        return AllPackets.VALUE_SETTINGS;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ValueSettingsPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipLargerStreamCodecs;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;

import java.util.function.BiConsumer;
import net.minecraft.class_1268;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_3244;
import net.minecraft.class_3965;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ValueSettingsPacket(
    class_2338 pos, int row, int value, class_1268 interactHand, class_3965 hitResult, class_2350 side, boolean ctrlDown, int behaviourIndex
) implements C2SPacket {
    public static final class_9139<class_9129, ValueSettingsPacket> CODEC = CatnipLargerStreamCodecs.composite(
        class_2338.field_48404,
        ValueSettingsPacket::pos,
        class_9135.field_48550,
        ValueSettingsPacket::row,
        class_9135.field_48550,
        ValueSettingsPacket::value,
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.HAND),
        ValueSettingsPacket::interactHand,
        CatnipStreamCodecBuilders.nullable(CatnipStreamCodecs.BLOCK_HIT_RESULT),
        ValueSettingsPacket::hitResult,
        class_2350.field_48450,
        ValueSettingsPacket::side,
        class_9135.field_48547,
        ValueSettingsPacket::ctrlDown,
        class_9135.field_48550,
        ValueSettingsPacket::behaviourIndex,
        ValueSettingsPacket::new
    );

    @Override
    public boolean runInMain() {
        return true;
    }

    @Override
    public class_9145<ValueSettingsPacket> method_65080() {
        return AllPackets.VALUE_SETTINGS;
    }

    @Override
    public BiConsumer<class_3244, ValueSettingsPacket> callback() {
        return AllHandle::onValueSettings;
    }
}
